@@ -68,7 +68,7 @@ get_dirs (void)
 	{
 		while ((dent = readdir (dir)))
 		{
-                        gchar* gtkrc_path = g_strconcat(dent->d_name, "/gtk-2.0/gtkrc", NULL);
+                        gchar* gtkrc_path = g_strconcat(dent->d_name, "/gtk/gtkrc", NULL);
 			stat(dent->d_name,&stats);
 			if (!S_ISDIR(stats.st_mode)) continue;
 			if (strcmp(dent->d_name,"." ) == 0) continue;
@@ -91,7 +91,7 @@ get_dirs (void)
 	{
 		while ((dent = readdir (dir)))
 		{
-                        gchar* gtkrc_path = g_strconcat(dent->d_name, "/gtk-2.0/gtkrc", NULL);
+                        gchar* gtkrc_path = g_strconcat(dent->d_name, "/gtk/gtkrc", NULL);
 			stat(dent->d_name,&stats);
 			if (!S_ISDIR(stats.st_mode)) continue;
 			if (strcmp(dent->d_name, "." ) == 0) continue;
